@@ -111,7 +111,7 @@ class ManualTrack:
             return self.length / self.elapsed_time.total_seconds()
         raise AttributeError(f"{self.__class__.__qualname__} has no average {field}")
 
-    def __contains__(self, _):
+    def __contains__(*_):
         return False
 
 
@@ -266,7 +266,9 @@ class Track:
     def calculate_gradient(self):
         """Calculate the gradient at each point."""
         self.fields["gradient"] = [None]
-        for dist, height_change in zip(self["dist_to_last"], self["height_change"])[1:]:
+        for dist, height_change in list(
+            zip(self["dist_to_last"], self["height_change"])
+        )[1:]:
             self.fields["gradient"].append(
                 None if dist in {None, 0} else height_change / dist
             )
@@ -341,13 +343,13 @@ class Track:
 
     @property
     @lru_cache(128)
-    def elapsed_time(self):
+    def elapsed_time(self) -> timedelta:
         end_time = self["time"][-1]
         return end_time - self.start_time
 
     @property
     @lru_cache(128)
-    def moving_time(self):
+    def moving_time(self) -> timedelta:
         total_time = timedelta(0)
         last_distance = 0
         last_time = self.start_time
